<!DOCTYPE TS><TS>
<context>
    <name>EditMetadataDialog</name>
    <message>
        <source>Level %1</source>
        <translation>Livello %1</translation>
    </message>
    <message>
        <source>None</source>
        <translation>None</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Nessuna copertina</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
</context>
<context>
    <name>FileAssocDialog</name>
    <message>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Please enter the new extension:</source>
        <translation>Prego inserisci la nuova estensione:</translation>
    </message>
    <message>
        <source>Create new extension</source>
        <translation>Crea una nuova estensione</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory that holds videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo only needs to have read permission to the directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting Parental Level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4 - Highest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 - Lowest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parental Control PIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, you will not be able to return to this screen and reset the Parental PIN without first entering the current PIN. You have been warned.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Unknown File Types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video List browses files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Player Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">Pin parentale:</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Nessuna copertina</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Sconosciuto</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Newly scanned files are browsable by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, newly scanned files in the Video Manager will be marked as browsable and will appear in the &apos;Browse&apos; menu.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This PIN is used to control the current Parental Level. If you want to use this feature, then setting the value to all numbers will make your life much easier.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to search for movie listings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This command must be executable by the user running MythVideo.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to search for movie posters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Command to extract data for movies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Directory that holds movie posters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This directory must exist, and the user running MythVideo needs to have read/write permission to the directory.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not retrieve poster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A movie poster exists for this movie but Myth could not retrieve it within a reasonable amount of time.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Listings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Aggressive Parental Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This is the command used for any file that the extension is not specifically defined. You may also enter the name of one of the playback plugins such as &apos;Internal&apos;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rows to display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Columns to display</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show title below thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the additional text will make the thumbnails smaller.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maintain aspect ratio of thumbnails</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, the scaled thumbnails will maintain their original aspect ratio. If not set, they are scaled to match the size of the background icon.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Browser browses files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Gallery browses files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings (1/2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>General Settings (2/2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video List Loads Video Meta Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sorting ignores case</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, case is ignored when sorting entries in a view.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show folders for database views</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If set, sub folders of your video directory will be shown in supported views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image cache size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This setting determines the number of images MythVideo will cache for views.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>^(The |A |An )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished">Tutti</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished">No</translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Year</source>
        <translation type="unfinished">Anno</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation type="unfinished">Giudizio</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation type="unfinished">Durata</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video ID</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeUI</name>
    <message>
        <source>Director:</source>
        <translation>Regia:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Anno:</translation>
    </message>
    <message>
        <source>Rated:</source>
        <translation>Quotato:</translation>
    </message>
    <message>
        <source>Parental Level:</source>
        <translation>Livello parentale:</translation>
    </message>
    <message>
        <source>Browsable:</source>
        <translation>Sfogliabile:</translation>
    </message>
    <message>
        <source>Runtime:</source>
        <translation>Durata:</translation>
    </message>
    <message>
        <source>Plot:</source>
        <translation>Trama:</translation>
    </message>
    <message>
        <source>Filename:</source>
        <translation>Nome file:</translation>
    </message>
    <message>
        <source>Cover File:</source>
        <translation>Copertina:</translation>
    </message>
    <message>
        <source>IMDB Num.:</source>
        <translation>Num. IMDB:</translation>
    </message>
    <message>
        <source>retrieving data...</source>
        <translation>Recupero dati...</translation>
    </message>
    <message>
        <source>[ looking for ]</source>
        <translation>[ ricerca di ]</translation>
    </message>
    <message>
        <source>Enter IMDB #</source>
        <translation>Inserisci IMDB #</translation>
    </message>
    <message>
        <source>loading...</source>
        <translation>caricamento...</translation>
    </message>
    <message>
        <source>No Videos Found</source>
        <translation>Nessun video trovato</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>Directed by</source>
        <translation>Diretto da</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>File:</translation>
    </message>
    <message>
        <source>Player:</source>
        <translation>Player:</translation>
    </message>
    <message>
        <source>PL </source>
        <translation>PL</translation>
    </message>
    <message>
        <source>MythVideo File Associations</source>
        <translation>Mythvideo Associazione File</translation>
    </message>
    <message>
        <source>Extension:</source>
        <translation>Estensione:</translation>
    </message>
    <message>
        <source>Command:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <source>Use default player:</source>
        <translation>Usa il player di default:</translation>
    </message>
    <message>
        <source>Ignore:</source>
        <translation>Ignora:</translation>
    </message>
    <message>
        <source>Edit Video Information</source>
        <translation>Modifica informazioni video</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Parental Control:</source>
        <translation>Controllo parentale:</translation>
    </message>
    <message>
        <source>File to Always Play Next:</source>
        <translation>File da eseguire in seguito:</translation>
    </message>
    <message>
        <source>Include while Browsing:</source>
        <translation>Includi mentre sfogli:</translation>
    </message>
    <message>
        <source>Cover Art:</source>
        <translation>Cover Art:</translation>
    </message>
    <message>
        <source>Unique Player Command:</source>
        <translation>Comando personalizzato:</translation>
    </message>
    <message>
        <source>/path/to/the/thing.jpg</source>
        <translation>/percorso/a/oggetto.jpg</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Categoria:</translation>
    </message>
    <message>
        <source>Filters video list</source>
        <translation>Filtri sulla lista dei film</translation>
    </message>
    <message>
        <source>Category :</source>
        <translation>Categoria:</translation>
    </message>
    <message>
        <source>Genre :</source>
        <translation>Genere:</translation>
    </message>
    <message>
        <source>Country :</source>
        <translation>Nazione:</translation>
    </message>
    <message>
        <source>Year :</source>
        <translation>Anno:</translation>
    </message>
    <message>
        <source>Runtime :</source>
        <translation>Durata:</translation>
    </message>
    <message>
        <source>User Rating :</source>
        <translation>Giudizio:</translation>
    </message>
    <message>
        <source>Browse :</source>
        <translation>Scorri:</translation>
    </message>
    <message>
        <source>Sort by :</source>
        <translation>Ordina per:</translation>
    </message>
    <message>
        <source>Aucune video</source>
        <translation></translation>
    </message>
    <message>
        <source>SELECT: Edit</source>
        <translation>SELECT: Modifica</translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <source>Parental</source>
        <translation>Parentale</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Livello</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Anno</translation>
    </message>
    <message>
        <source>Runtime</source>
        <translation>Durata</translation>
    </message>
    <message>
        <source>User Rating</source>
        <translation>Giudizio</translation>
    </message>
    <message>
        <source>INFO - Action Menu</source>
        <translation>INFO - Menu azione</translation>
    </message>
    <message>
        <source>Up/Down, Page Up/Down: Browse   MENU: Options   INFO: Action Menu</source>
        <translation>Sù/Giù, Pagina sù/giù: Scorri   MENU: Opzioni   INFO: Menu azione</translation>
    </message>
    <message>
        <source>Play File After This:</source>
        <translation>Esegui successivamente:</translation>
    </message>
</context>
<context>
    <name>VideoBrowser</name>
    <message>
        <source>%1 of %2</source>
        <translation>%1 di %2</translation>
    </message>
    <message>
        <source>No Videos</source>
        <translation>Nessun video</translation>
    </message>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">Nessun rating disponibile.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minuti</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Guarda questo film</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Vedi la trama completa</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Visualizzazione filtrata</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>VideoDialog</name>
    <message>
        <source>Switch to Browse View</source>
        <translation>Cambia vista a scorrimento</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Cambia vista a galleria</translation>
    </message>
    <message>
        <source>Switch to List View</source>
        <translation>Cambia vista a lista</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Seleziona azione</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">Pin parentale:</translation>
    </message>
</context>
<context>
    <name>VideoFilterDialog</name>
    <message>
        <source>Result of this filter : %1 video(s)</source>
        <translation>Risultati di questo filtro: %1 film</translation>
    </message>
    <message>
        <source>Result of this filter : No Videos</source>
        <translation>Risultato di questo filtro: Nessun film</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Sconosciuto</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuti</translation>
    </message>
    <message>
        <source>All</source>
        <translation type="obsolete">Tutti</translation>
    </message>
    <message>
        <source>Save as default</source>
        <translation>Salva come default</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fatto</translation>
    </message>
</context>
<context>
    <name>VideoGallery</name>
    <message>
        <source>Filter Display</source>
        <translation>Visualizzazione filtrata</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Guarda questo film</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Vedi la trama completa</translation>
    </message>
    <message>
        <source>View Details</source>
        <translation>Vedi dettagli</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>VideoManager</name>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minuti</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">No</translation>
    </message>
    <message>
        <source>No Cover</source>
        <translation type="obsolete">Nessuna copertina</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="obsolete">Sconosciuto</translation>
    </message>
    <message>
        <source>None</source>
        <translation type="obsolete">Nessuno</translation>
    </message>
    <message>
        <source>NR</source>
        <translation type="obsolete">NR</translation>
    </message>
    <message>
        <source>delete failed</source>
        <translation>cancellazione fallita</translation>
    </message>
    <message>
        <source>Select action:</source>
        <translation>Seleziona azione:</translation>
    </message>
    <message>
        <source>Edit Metadata</source>
        <translation>Modifica metadati</translation>
    </message>
    <message>
        <source>Search IMDB</source>
        <translation>Cerca IMDB</translation>
    </message>
    <message>
        <source>Manually Enter IMDB #</source>
        <translation>Inserisci il # di IMDB</translation>
    </message>
    <message>
        <source>Reset Metadata</source>
        <translation>Resetta metadata</translation>
    </message>
    <message>
        <source>Toggle Browseable</source>
        <translation>Scambia scorrimento</translation>
    </message>
    <message>
        <source>Remove Video</source>
        <translation>Rimuovi il film</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Visualizzazione filtrata</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Delete this file?</source>
        <translation>Elimino questo file?</translation>
    </message>
</context>
<context>
    <name>VideoSelected</name>
    <message>
        <source>No rating available.</source>
        <translation type="obsolete">Nessun rating disponibile.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">minuti</translation>
    </message>
</context>
<context>
    <name>VideoTree</name>
    <message>
        <source>Parental Pin:</source>
        <translation type="obsolete">Pin parentale:</translation>
    </message>
    <message>
        <source>Select action</source>
        <translation>Seleziona azione</translation>
    </message>
    <message>
        <source>Watch This Video</source>
        <translation>Guarda questo film</translation>
    </message>
    <message>
        <source>View Full Plot</source>
        <translation>Vedi la trama completa</translation>
    </message>
    <message>
        <source>Filter Display</source>
        <translation>Visualizzazione filtrata</translation>
    </message>
    <message>
        <source>Switch to Browse View</source>
        <translation>Cambia vista a scorrimento</translation>
    </message>
    <message>
        <source>Switch to Gallery View</source>
        <translation>Cambia vista a galleria</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
</TS>
